==> django-secretary_0.2.0.orig.tar.gz: django-secretary-0.2.0/django_secretary/settings.py <==
"""Application settings for django-secretary."""
from functools import partial
from typing import Dict, Mapping, cast

from appsettings import AppSettings, CallablePathSetting, DictSetting, NestedListSetting
from django.conf import settings
from django.core.exceptions import ValidationError
from django.utils.translation import gettext_lazy as _

from .renderers import HtmlRenderer, PdfRenderer, TextRenderer

_DEFAULT_RENDERERS = (HtmlRenderer, TextRenderer, PdfRenderer)
DEFAULT_STATE_FLAGS_DESCRIPTIONS = {
    'deleteCandidate': _('To be deleted'),
    'linked': _('Has relation to other records in the registry'),
    'serverBlocked': _('Administratively blocked'),
    'conditionallyIdentifiedContact': _('Contact is conditionally identified'),
    'identifiedContact': _('Contact is identified'),
    'validatedContact': _('Contact is validated'),
    'serverDeleteProhibited': _('Deletion forbidden'),
    'serverTransferProhibited': _('Sponsoring registrar change forbidden'),
    'serverUpdateProhibited': _('Update forbidden'),
    'serverRegistrantChangeProhibited': _('Registrant change forbidden'),
    'serverRenewProhibited': _('Registration renewal forbidden'),
    'expirationWarning': _('The domain expires in 30 days'),
    'deleteWarning': _('The domain will be deleted in 11 days'),
    'validationWarning1': _('The domain validation expires in 30 days'),
    'validationWarning2': _('The domain validation expires in 15 days'),
    'unguarded': _('The domain is 30 days after expiration'),
    'outzoneUnguarded': _('The domain is out of zone after 30 days in expiration state'),
    'nssetMissing': _("The domain doesn't have associated nsset"),
    'expired': _('Domain expired'),
    'outzone': _("The domain isn't generated in the zone"),
    'serverOutzoneManual': _('The domain is administratively kept out of zone'),
    'serverInzoneManual': _('The domain is administratively kept in zone'),
    'notValidated': _('Domain not validated'),
    'outzoneUnguardedWarning': _('The domain is to be out of zone soon.'),
}


class MergeDictSetting(DictSetting):
    """Merge dict setting."""

    def transform(self, value: Dict) -> Dict:
        """Merge setting value with the defaults."""
        result = cast(Dict, self.default.copy())
        result.update(value)
        return result


class SignersSetting(DictSetting):
    """Custom setting for SIGNERS."""

    def validate(self, value: Dict[str, Dict]) -> None:
        """Check structure of signer settings."""
        for val in value.values():
            if 'COMMAND' not in val:
                raise ValidationError("Every signer needs a COMMAND key.")
            if not isinstance(val['COMMAND'], (list, tuple)) or not all(isinstance(i, str) for i in val['COMMAND']):
                raise ValidationError("COMMAND has to be a sequence of strings.")
            if 'ENVIRONMENT' in val and not isinstance(val['ENVIRONMENT'], Mapping):
                raise ValidationError("ENVIRONMENT has to be a mapping.")
            if 'OUTPUT' in val and not isinstance(val['OUTPUT'], str):
                raise ValidationError("OUTPUT has to be a string.")

    def transform(self, value: Dict[str, Dict]) -> Dict[str, Dict]:
        """Set defaults for signer settings."""
        for val in value.values():
            val.setdefault('ENVIRONMENT', None)
            val.setdefault('OUTPUT', "{basename}_signed")
        return value


class SecretaryAppSettings(AppSettings):
    """Django-secretary application settings."""

    RENDERERS = NestedListSetting(inner_setting=CallablePathSetting(), default=_DEFAULT_RENDERERS)
    SIGNERS = SignersSetting(key_type=str, value_type=dict)
    TEMPLATES = NestedListSetting(inner_setting=DictSetting(key_type=str),
                                  default=partial(getattr, settings, 'TEMPLATES'))
    STATE_FLAGS_DESCRIPTIONS = DictSetting(key_type=str, default=DEFAULT_STATE_FLAGS_DESCRIPTIONS)

    class Meta:
        setting_prefix = 'SECRETARY_'


SECRETARY_SETTINGS = SecretaryAppSettings()

==> django-secretary_0.5.2.orig.tar.gz: django-secretary-0.5.2/django_secretary/settings.py <==
"""Application settings for django-secretary."""
from functools import partial
from typing import Dict, Mapping, cast

from appsettings import AppSettings, CallablePathSetting, DictSetting, NestedListSetting
from django.conf import settings
from django.core.exceptions import ValidationError
from django.utils.translation import gettext_lazy as _

from .renderers import HtmlRenderer, PdfRenderer, TextRenderer

_DEFAULT_RENDERERS = (HtmlRenderer, TextRenderer, PdfRenderer)
DEFAULT_STATE_FLAGS_DESCRIPTIONS = {
    'deleteCandidate': _('To be deleted'),
    'linked': _('Has relation to other records in the registry'),
    'serverBlocked': _('Administratively blocked'),
    'conditionallyIdentifiedContact': _('Contact is conditionally identified'),
    'identifiedContact': _('Contact is identified'),
    'validatedContact': _('Contact is validated'),
    'serverDeleteProhibited': _('Deletion forbidden'),
    'serverTransferProhibited': _('Sponsoring registrar change forbidden'),
    'serverUpdateProhibited': _('Update forbidden'),
    'serverRegistrantChangeProhibited': _('Registrant change forbidden'),
    'serverRenewProhibited': _('Registration renewal forbidden'),
    'expirationWarning': _('The domain expires in 30 days'),
    'deleteWarning': _('The domain will be deleted in 11 days'),
    'validationWarning1': _('The domain validation expires in 30 days'),
    'validationWarning2': _('The domain validation expires in 15 days'),
    'unguarded': _('The domain is 30 days after expiration'),
    'outzoneUnguarded': _('The domain is out of zone after 30 days in expiration state'),
    'nssetMissing': _("The domain doesn't have associated nsset"),
    'expired': _('Domain expired'),
    'outzone': _("The domain isn't generated in the zone"),
    'serverOutzoneManual': _('The domain is administratively kept out of zone'),
    'serverInzoneManual': _('The domain is administratively kept in zone'),
    'notValidated': _('Domain not validated'),
    'outzoneUnguardedWarning': _('The domain is to be out of zone soon.'),
    'serverLinkProhibited': _('Contact linking forbidden'),
    'premiumDomain': _('VIP domain'),
}


class MergeDictSetting(DictSetting):
    """Merge dict setting."""

    def transform(self, value: Dict) -> Dict:
        """Merge setting value with the defaults."""
        result = cast(Dict, self.default.copy())
        result.update(value)
        return result


class SignersSetting(DictSetting):
    """Custom setting for SIGNERS."""

    def validate(self, value: Dict[str, Dict]) -> None:
        """Check structure of signer settings."""
        for val in value.values():
            if 'COMMAND' not in val:
                raise ValidationError("Every signer needs a COMMAND key.")
            if not isinstance(val['COMMAND'], (list, tuple)) or not all(isinstance(i, str) for i in val['COMMAND']):
                raise ValidationError("COMMAND has to be a sequence of strings.")
            if 'ENVIRONMENT' in val and not isinstance(val['ENVIRONMENT'], Mapping):
                raise ValidationError("ENVIRONMENT has to be a mapping.")
            if 'OUTPUT' in val and not isinstance(val['OUTPUT'], str):
                raise ValidationError("OUTPUT has to be a string.")

    def transform(self, value: Dict[str, Dict]) -> Dict[str, Dict]:
        """Set defaults for signer settings."""
        for val in value.values():
            val.setdefault('ENVIRONMENT', None)
            val.setdefault('OUTPUT', "input_signed.pdf")
        return value


class SecretaryAppSettings(AppSettings):
    """Django-secretary application settings."""

    RENDERERS = NestedListSetting(inner_setting=CallablePathSetting(), default=_DEFAULT_RENDERERS)
    SIGNERS = SignersSetting(key_type=str, value_type=dict)
    TEMPLATES = NestedListSetting(inner_setting=DictSetting(key_type=str),
                                  default=partial(getattr, settings, 'TEMPLATES'))
    STATE_FLAGS_DESCRIPTIONS = MergeDictSetting(key_type=str, default=DEFAULT_STATE_FLAGS_DESCRIPTIONS)

    class Meta:
        setting_prefix = 'SECRETARY_'


SECRETARY_SETTINGS = SecretaryAppSettings()
